@@ -9,6 +9,7 @@ from .add_field import add_field
 from .checkpoint import checkpoint
 from .concatenate import concatenate
 from .delete_fields import delete_fields
+from .deduplicate import deduplicate
 from .duplicate import duplicate
 from .filter_rows import filter_rows
 from .find_replace import find_replace
@@ -21,3 +22,4 @@ from .unpivot import unpivot
 from .unstream import unstream
 from .update_package import update_package, add_metadata
 from .update_resource import update_resource
+from .update_schema import update_schema
